@@ -3,7 +3,7 @@ package App::ModuleBuildTiny;
 use 5.014;
 use strict;
 use warnings;
-our $VERSION = '0.037';
+our $VERSION = '0.038';
 
 use Exporter 5.57 'import';
 our @EXPORT = qw/modulebuildtiny/;
@@ -250,7 +250,7 @@ my %actions = (
 		my @arguments = @_;
 		$AUTHOR_TESTING = 1;
 		GetOptionsFromArray(\@arguments, 'release!' => \$RELEASE_TESTING, 'author!' => \$AUTHOR_TESTING, 'automated!' => \$AUTOMATED_TESTING,
-			'extended!' => \$EXTENDED_TESTING, 'non-interactive!' => \$NONINTERACTIVE_TESTING) or return 2;
+			'extended!' => \$EXTENDED_TESTING, 'non-interactive!' => \$NONINTERACTIVE_TESTING, 'jobs=i' => \my $jobs) or return 2;
 		my @dirs = 't';
 		if ($AUTHOR_TESTING) {
 			push @dirs, catdir('xt', 'author');
@@ -260,6 +260,8 @@ my %actions = (
 		push @dirs, catdir('xt', 'extended') if $EXTENDED_TESTING;
 		@dirs = grep -e, @dirs;
 		my $dist = App::ModuleBuildTiny::Dist->new;
+		my @args;
+		push @args, '-j', $jobs if defined $jobs;
 		return $dist->run(command => [ 'prove', '-br', @dirs ], build => 1, verbose => 1);
 	},
 	upload => sub {
@@ -442,7 +444,7 @@ my %actions = (
 
 		my $settings = get_settings(\%default_settings);
 
-		my $distname = decode_utf8(shift @arguments // die "No distribution name given\n");
+		my $distname = decode_utf8(shift @arguments // die "No distribution name given\n") =~ s/::/-/gr;
 
 		my %args = (
 			author   => $settings->{author},
@@ -476,6 +478,7 @@ my %actions = (
 		write_changes(%args, distname => $distname);
 		write_maniskip($distname);
 		write_json('dist.json', \%config);
+		mkdir 't';
 
 		write_json('metamerge.json', { name => $distname }) if $distname ne $args{dirname};
 
